@@ -6,9 +6,9 @@ class Field(BaseField):
 
     database_type = DATABASE_TYPES["PostgreSQL"]
     field_type = None
-    __value = None
 
     def __init__(self, verbose_name=None, null=False, unique=False, primary_key=False, default=None, extra_sql=()):
+        self.__value = None
         self.verbose_name = verbose_name
         self.primary_key = primary_key
         if primary_key:
@@ -135,3 +135,6 @@ class ForeignKeyField(Field):
             value = self.table_name.objects.get(pk=self.field.convert(value))
             return value
         return None
+
+    def set_value(self, value):
+        self.__value = value
