@@ -104,7 +104,13 @@ class RowSet:
         if len(self.__table_columns) == len(self.__columns_order):
             for k in self.__table_columns:
                 field = "{}.{}.{}".format(schema, table_name, k)
-                obj.__dict__[k] = data_map[field]
+                if isinstance(self.__table_class.__dict__[k], datatypes.ForeignKeyField):
+                    obj_fk_table_name = getattr(self.__table_class.__dict__[k], "table_name")
+                    fk_obj = obj_fk_table_name()
+                    fk_obj.set_pk(data_map[field])
+                    obj.__dict__[k] = fk_obj
+                else:
+                    obj.__dict__[k] = data_map[field]
         elif len(self.__table_columns) < len(self.__columns_order):
             obj = model_obj_set_attr(self.__table_class, obj)
         return obj
